<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'plugin را فعال کنید',
	'affichage' => 'ارايه',
	'aide_non_disponible' => 'اين بخش كمكى براى اين زبان هنوز در دسترس نمى باشد',
	'annuler_recherche' => 'لغو جستجو',
	'auteur' => 'نویسنده:',
	'avis_acces_interdit' => 'دسترسى به اين بخش ممنوع مى باشد',
	'avis_article_modifie' => 'توجه ،              @nom_auteur_modif@                                        روى اين مقاله @date_diff@ پيش كار ميكرده',
	'avis_aucun_resultat' => '.بدون نتيجه',
	'avis_base_inaccessible' => 'دسترسي به پايگاه داده‌هاي @base@ ممكن نيست. ',
	'avis_chemin_invalide_1' => 'راهى كه انتخاب كرده ايد',
	'avis_chemin_invalide_2' => 'معتبر نميباشد. خواهشمند است به صفحه پيشين برگرديد و اطلاعات داده شده را بازنگرى كنيد',
	'avis_connexion_echec_1' => 'ارتباط با پايگاه داده‌‌ها  برقرار نشد',
	'avis_connexion_echec_2' => 'به صفحه پيشين برگرديد و اطلاعاتي را كه داده ايد بازنگرى كنيد',
	'avis_connexion_echec_3' => 'براى تعدادى از سرورها شما بايد درخواست فعال كردن دسترسى به پايگاه ماى اس كيو ال را پيش از استفاده آن بكنيد. اگر ارتباط برقرار نشد مطمئن شويد كه اين كار را انجام داده ايد              ',
	'avis_connexion_erreur_nom_base' => 'نام پايگاه نمي‌تواند چيزي جز حروف، ارقام و خط تيره باشد',
	'avis_connexion_ldap_echec_1' => 'LDAP.ارتباط با سرور ال دى ا پى برقرار نشد                ',
	'avis_connexion_ldap_echec_2' => 'به صفحه پيش برگرديد و ببينيد اطلاعاتي را كه داده ايد صحيح ميباشند',
	'avis_connexion_ldap_echec_3' => 'از سيستم ال دى ا پى به طور پى در پى براى ورود كاربران استفاده نكنيد',
	'avis_deplacement_rubrique' => 'توجه ! اين بخش داراى@contient_breves@ brève@scb@ ميباشد : خواهشمند است درصورت جابجائي آن، علامت مربوطه را تائيد كنيد ',
	'avis_erreur_connexion_mysql' => 'خطاى اتصال SQL   ',
	'avis_espace_interdit' => '<b>بخش ممنوع</b><p> اسپيپ قبلأ نصب شده',
	'avis_lecture_noms_bases_1' => '  برنامه نصبى نتوانست نام داده پى هاى مستقر شده را بخواند ',
	'avis_lecture_noms_bases_2' => '  يا هيچ پايگاهى موجود نميباشد، يا كاركردى كه اجازه فهرست گذارى پايگاه ها راميدهد بدلايل ايمنى غير فعال شده است     (مورد بعضى از ميزبانان ميباشد)',
	'avis_lecture_noms_bases_3' => ' در  گزينش دوم، اين احتمال وجود دارد كه پايگاهى   كه حامل نام شما براى ارتباط ميباشد استفاده شده باشد',
	'avis_non_acces_page' => 'اين صفحه در دسترس شما نميباشد',
	'avis_operation_echec' => 'کارکرد نتیجه نداد.',
	'avis_operation_impossible' => 'عمل غیرممکن',
	'avis_suppression_base' => ' توجه! حذف داده ها غير قابل برگشت ميباشد',

	// B
	'bouton_acces_ldap' => 'دسترسى به LDAP را اضافه كنيد',
	'bouton_ajouter' => 'اضافه كنيد',
	'bouton_annuler' => 'باطل کنید',
	'bouton_cache_activer' => 'بازفعال سازي حافظه پنهان',
	'bouton_cache_desactiver' => 'غيرفعال سازي موقت حافظه پنهان ',
	'bouton_demande_publication' => 'انتشار اين مقاله را درخواست كنيد  ',
	'bouton_desactive_tout' => 'همه را غیر فعال کنید',
	'bouton_desinstaller' => 'حذف کنید',
	'bouton_effacer_tout' => 'همه را پاك كنيد',
	'bouton_envoyer_message' => 'پيام آماده : بفرستيد',
	'bouton_fermer' => 'بستن',
	'bouton_mettre_a_jour_base' => 'به هنگام سازي پايگاه داده‌ها',
	'bouton_modifier' => 'اصلاح كنيد',
	'bouton_radio_afficher' => 'نشان دهيد',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'در فهرست نويسندگانى كه به اسپيپ وصل هستند ظاهر شود',
	'bouton_radio_envoi_annonces_adresse' => ':خبرها را به اين آدرس بفرستيد',
	'bouton_radio_envoi_liste_nouveautes' => 'فهرست تازه ها را بفرستيد:',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'در فهرست نويسندها نمايان نشود',
	'bouton_radio_non_envoi_annonces_editoriales' => 'خبرهاى مربوط به سر مقاله ها را نفرستيد',
	'bouton_redirection' => 'هدايت دوباره',
	'bouton_relancer_installation' => 'دوباره نصب كنيد',
	'bouton_suivant' => 'بعدى',
	'bouton_tenter_recuperation' => 'اقدام به تعمير كنيد',
	'bouton_test_proxy' => 'پروكسى را امتحان كنيد',
	'bouton_vider_cache' => 'فايل موقت را خالى كنيد',

	// C
	'cache_modifiable_webmestre' => 'اين پارامترها توسط وب مستر سايت ميتواند اصلاح شود.',
	'calendrier_synchro' => ' درصورت استفاده از نرم افزارهاى روزشمار ويژه<b>iCal</b>, ميتوانيد آنرا با مطالب اين سايت منطبق كنيد',
	'config_activer_champs' => 'بخشهای زیر را فعال کنید',
	'config_choix_base_sup' => 'يك پايگاه روي اين سرور تعيين كنيد',
	'config_erreur_base_sup' => 'اسپيپ به فهرست پايگاه‌هاي قابل دسترس دسترسي ندارد',
	'config_info_base_sup' => 'اگر شما پايگاه داده‌هاي ديگري براي امتحان از طريق اسپيپ داريد، با سرور اس.كيو.ال يا غير آن، بگذاريد كه آن‌ها آشكار شوند. اگر بعضي از ميدان‌ها را خالي بگذاريد، شناسه‌هاي ارتباط با پايگاه اصلي مورد استفاده قرار خواهند گرفت. ',
	'config_info_base_sup_disponibles' => 'پايگاه‌هاي مكمل اكنون جستجوپذير اند',
	'config_info_enregistree' => 'پيكربندي جديد ثبت شده',
	'config_info_logos' => 'هر قسمت سایت میتواند یک لوگو logo و یک لوگوی survol داشته باشد',
	'config_info_logos_utiliser' => 'از لوگوها استفاده کنید',
	'config_info_logos_utiliser_non' => 'از لوگوها استفاده نکنید',
	'config_info_logos_utiliser_survol' => 'از لوگوهای survol استفاده کنید',
	'config_info_logos_utiliser_survol_non' => 'از لوگوهای survol استفاده نکنید',
	'config_info_redirection' => 'با فعال کردن این گزینش شما میتوانید مقالات مجازی درست کنید و یا مراجع مقالات منتشر شده در دیگر سایتها را بدهید',
	'config_redirection' => 'مقالات مجازی',
	'config_titre_base_sup' => 'اعلام يك پايگاه مكمل',
	'config_titre_base_sup_choix' => 'يك پايگاه مكمل انتخاب كنيد',
	'connexion_ldap' => 'ارتباط',
	'creer_et_associer_un_auteur' => 'ايجاد و اتصال نويسنده',

	// D
	'date_mot_heures' => 'ساعت',

	// E
	'ecran_securite' => '+ نمايشگر ايمني @version@',
	'email' => 'ايميل',
	'email_2' => ': ايميل ',
	'en_savoir_plus' => 'براي آگاهي بيشتر ',
	'entree_adresse_annuaire' => 'آدرس راهنما',
	'entree_adresse_email' => 'آدرس ايميل شما ',
	'entree_adresse_email_2' => 'نشاني ايميل ',
	'entree_base_donnee_1' => 'آدرس داده پى ها',
	'entree_base_donnee_2' => 'اغلب, اين آدرس با آدرس سايتتون مطابقت ميكند گاهى با گزينش «localhost»  مطابقت و گاهى كاملأ خاليست)',
	'entree_biographie' => 'زندگينامه كوتاه در چند كلمه',
	'entree_chemin_acces' => ' راه ورود </b> وارد شويد <b>',
	'entree_cle_pgp' => 'PGP كليد شما          ',
	'entree_cle_pgp_2' => 'كليد پي.چي.پي',
	'entree_contenu_rubrique' => '(محتوى اين بخش در چند كلمه)',
	'entree_identifiants_connexion' => 'كلمه شناسائى براى متصل شدن',
	'entree_identifiants_connexion_2' => 'شناسه‌ي ارتباط',
	'entree_informations_connexion_ldap' => 'LDAP     خواهشمند است، اطلاعات مربوط به ارتباط به راهنماى  ال دى ا پى را در اين پرسشنامه وارد كنيد.
 اين ااطلاعات ميبايد توسط گرداننده  سيستم 
يا شبكه به شما داده شود',
	'entree_infos_perso' => ' كى هستيد؟',
	'entree_infos_perso_2' => 'نويسنده كيست؟',
	'entree_interieur_rubrique' => ': در داخل اين بخش',
	'entree_liens_sites' => '<b>ارتباط hypertexte</b> (.مراجع , سايت هايي براى بازديد )',
	'entree_login' => 'شما login',
	'entree_login_connexion_1' => 'ارتباط login',
	'entree_login_connexion_2' => '(مطابقت ميكند، گاهى خالى گذاشته شده  FTPورود به login گاهى با)    ',
	'entree_mot_passe' => 'كلمه ورودتان',
	'entree_mot_passe_1' => '(كلمه ورود براى ارتباط (كنكشن',
	'entree_mot_passe_2' => '(مطابقت ميكند، گاهى خالى گذاشته شده FTP گاهى با كلمه ورود )      ',
	'entree_nom_fichier' => '@texte_compresse@:خواهشمند است نام فايل را داخل بنمائيد',
	'entree_nom_pseudo' => 'نام يا نام مستعارتان',
	'entree_nom_pseudo_1' => '(نام يا نام مستعارتان)',
	'entree_nom_pseudo_2' => 'نام يا نام مستعار',
	'entree_nom_site' => 'نام سايتتان',
	'entree_nom_site_2' => 'نام سايت نويسنده',
	'entree_nouveau_passe' => 'كلمه ورود جديد',
	'entree_passe_ldap' => 'كلمه ورود',
	'entree_port_annuaire' => 'شماره وردى راهنما',
	'entree_signature' => 'امضاء',
	'entree_titre_obligatoire' => '</b>عنوان<b> [اجبارى]<br />',
	'entree_url' => '(URL) آدرس سايتتان',
	'entree_url_2' => 'آدرس (يو.آر.ال) سايت',
	'erreur_connect_deja_existant' => 'سروري به نام     موجود است',
	'erreur_email_deja_existant' => 'اين نشاني ايميل قبلاً ثبت شده است.',
	'erreur_nom_connect_incorrect' => 'نام سرور مجاز نيست',
	'erreur_plugin_desinstalation_echouee' => 'نصب زدايي پلاگين موفق نبود. با اين وجود مي‌توانيد آن را غيرفعال سازيد.',
	'erreur_plugin_fichier_absent' => 'فایل موجود نیست',
	'erreur_plugin_fichier_def_absent' => 'فایل معیار موجود نیست',
	'erreur_plugin_nom_fonction_interdit' => 'نام تابع مجاز نمیباشد',
	'erreur_plugin_nom_manquant' => 'نام plugin یافت نمیشود',
	'erreur_plugin_prefix_manquant' => 'بخش نامگذاری plugin کامل نمیباشد',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; در فایل توضیحی موجود نمیباشد',
	'erreur_plugin_version_manquant' => 'نسخه ی plugin موجود نمیباشد',

	// H
	'htaccess_a_simuler' => 'هشدار:‌ پيكربندي HTTP سرور شما پرونده‌هاي @htaccess@ را ناديده مي‌گيرد. براي تضمين امنيت كافي،‌ بايد پيكربندي اين را عضو كنيد. يا مطمئن شويد ثابت‌هاي @constantes@ (تعريف شده در پرونده‌ي mes_options.ph) همان مقدار خارج از ديركتوار @document_root@ را دارد.  ',
	'htaccess_inoperant' => 'htaccess بي‌اثر',

	// I
	'ical_info1' => 'اين صفحه شيوه هاى گوناگونى را براى آگاهى از مسايل روزانه سايت معرفى ميكند.',
	'ical_info2' => 'براى آگاهى بيشتر از جزييات فنى به, <a href="@spipnet@">اسناد اسپيپ </a> مراجعه كنيد.',
	'ical_info_calendrier' => '٢ روزشمار در دسترس شما ميباشد.  روزشمار اول وضعيت سايت را همراه با خبرهاى مربوط به مقالات منتشره نشان ميدهد. روزشمار دوم حاوى مقالات تحريريه و آخرين پيامهاى خصوصى شما كه بواسطه يك كد شخصى تنها در درسترس شما ميباشد است. شما ميتوانيد آنرا در هر زمانى كه مايل باشيد تغيير دهيد. ',
	'ical_methode_http' => 'بارگذارى',
	'ical_methode_webcal' => 'مقارن كردن (webcal://)',
	'ical_texte_js' => 'يك برنامه جاوا اسكريپت بشما امكان اعلان مقالات تازه منتشر شده در اين سايت را در سايتهاى ديگر ميدهد.',
	'ical_texte_prive' => 'اين روزشمار شما را در جريان فعاليتهاى تحريريه ويژه سايت ميگذارد (كار, ملاقات هاى شخصى,  مقالات ...). ',
	'ical_texte_public' => 'اين روزشمار بشما امكان پيگيرى فعاليت هاى همگانى سايت را ميدهد (مقالات,...). ',
	'ical_texte_rss' => ' شما ميتوانيد تازه هاى اين سايت را با فايلهاى XML/RSS (Rich Site Summary)  بديگر سايتها پيوند دهيد.همچنين اين نوع فايل به اسپيپ امكان خواندن تازه هاى ديگر سايتها را ميدهد.',
	'ical_titre_js' => 'جاوا اسكريپت',
	'ical_titre_mailing' => 'ليست ايميلها',
	'ical_titre_rss' => ' فايل syndication',
	'icone_accueil' => 'خانه',
	'icone_activer_cookie' => 'كوكى مكاتبه را فعال كنيد',
	'icone_activite' => 'بازخورد',
	'icone_admin_plugin' => 'اداره ی plugins',
	'icone_administration' => 'نگه‌داري',
	'icone_afficher_auteurs' => 'فهرست نويسند گان را بروى صفحه نشان دهيد ',
	'icone_afficher_visiteurs' => ' فهرست بازديدكنند گان را بروى صفحه نشان دهيد ',
	'icone_arret_discussion' => 'ديگر در اين بحث شركت نكنيد',
	'icone_calendrier' => 'تقويم',
	'icone_configuration' => 'پيكربندي',
	'icone_creer_auteur' => 'يك نويسنده جديد اضافه و به اين مقاله مرتبطش كنيد',
	'icone_creer_mot_cle' => 'يك كليد-واژه نو بسازيد و به اين مقاله مرتبطش كنيد',
	'icone_creer_rubrique_2' => 'يك بخش جديد بسازيد',
	'icone_edition' => 'ويرايش',
	'icone_ma_langue' => 'زبان من',
	'icone_mes_infos' => 'اطلاعات من',
	'icone_mes_preferences' => 'ترجيح‌هاي من',
	'icone_modifier_article' => 'اين مقاله را اصلاح كنيد',
	'icone_modifier_rubrique' => 'اين بخش را اصلاح كنيد',
	'icone_publication' => 'انتشار',
	'icone_relancer_signataire' => 'بازنشر امضاء',
	'icone_retour' => 'بازگشت',
	'icone_retour_article' => 'بازگشت به مقاله',
	'icone_squelette' => 'اسكلت',
	'icone_suivi_publication' => 'پيگيري انتشارات',
	'icone_supprimer_cookie' => 'كوكى مكاتبه را حذف كنيد',
	'icone_supprimer_rubrique' => 'اين بخش را حذف كنيد',
	'icone_supprimer_signature' => 'اين امضاء را حذف كنيد',
	'icone_valider_signature' => 'اين امضاء را معتبر كنيد',
	'image_administrer_rubrique' => 'شما ميتوانيد اين بخش را اداره كنيد',
	'info_1_article' => '١ مقاله',
	'info_1_auteur' => 'نويسنده‌ي 1',
	'info_1_message' => 'پيام 1',
	'info_1_mot_cle' => 'كليدواژه‌ي 1',
	'info_1_rubrique' => 'بخش 1',
	'info_1_visiteur' => 'بازديد‌كننده‌ي 1',
	'info_activer_cookie' => ' شما ميتوانيد  كوكى مكاتبه  را فعال نماپيد اينكار به شما اجازه خواهد داد كه براحتى از سايت همگانى به سايت خصوصى برويد',
	'info_admin_etre_webmestre' => 'دادن حق وب مستر به من',
	'info_admin_je_suis_webmestre' => 'من <b>webmestre</b> هستم',
	'info_admin_statuer_webmestre' => 'تفويض حق وب مستري به اين مدير',
	'info_admin_webmestre' => 'اين مدير <b>webmestre</b> است',
	'info_administrateur' => 'گردانند سايت',
	'info_administrateur_1' => 'گرداننده  ',
	'info_administrateur_2' => '(<i>با احتياط استفاده كنيد </i>) سايت ',
	'info_administrateur_site_01' => 'اگر شما از گردانند گان سايت هستيد، خواهشمند است',
	'info_administrateur_site_02' => 'روى اين پيوند كليك كنيد',
	'info_administrateurs' => 'گردانند گان سايت',
	'info_administrer_rubrique' => 'شما ميتوانيد اين بخش را اداره كنيد',
	'info_adresse' => ': به آدرس',
	'info_adresse_desinscription' => 'نساني قطع آبونمان: ',
	'info_adresse_url' => '(URL) آدرس سايت همگانى      ',
	'info_afficher_par_nb' => 'نشان دادن با',
	'info_aide_en_ligne' => 'SPIP كمك در تارنما',
	'info_ajout_image' => '  هنگامى كه تصاويرى را ضميمه مقاله اى ميكنيد، اسپيپ ميتواند بطور خودكار آنها را بصورت كوچك شده اضافه كند. با اين روش ميتوان براى مثال نمايى از مجموع تصاوير را بطور خودكار درست كرد ',
	'info_ajouter_rubrique' => 'يك بخش ديگر را براى اداه كردن اضافه كنيد',
	'info_annonce_nouveautes' => 'خبر تازه ها',
	'info_article' => 'مقاله',
	'info_article_2' => 'مقاله',
	'info_article_a_paraitre' => 'مقالات با تاريخ آينده منتشر شوند',
	'info_articles_02' => 'مقالات',
	'info_articles_2' => 'مقالات',
	'info_articles_auteur' => 'مقالات اين نويسنده',
	'info_articles_miens' => 'مقالات من',
	'info_articles_tous' => 'تمام مقاله‌ها',
	'info_articles_trouves' => 'مقالات پيدا شده',
	'info_attente_validation' => 'مقاله هايتان در انتظار تأئيد شدن',
	'info_aucun_article' => 'مقاله‌اي نيست',
	'info_aucun_auteur' => 'هيچ مؤلفي موجود نيست',
	'info_aucun_message' => 'هيچ پيامي موجود نيست',
	'info_aucun_rubrique' => 'هيچ بخش',
	'info_aujourdhui' => ': امروز',
	'info_auteur_gere_toutes_rubriques_2' => 'من <b> تمام بخش‌ها را اداره مي‌كنم</b>', # MODIF
	'info_auteurs' => 'نويسندگان ',
	'info_auteurs_par_tri' => '@partri@ نويسنده گان',
	'info_auteurs_trouves' => 'نويسنده گان پيدا شده   ',
	'info_authentification_externe' => 'تأئيد از خارج',
	'info_avertissement' => 'تذكر',
	'info_barre_outils' => 'با ميل ابزار آن؟',
	'info_base_installee' => '.ساختار داده پى هايتان نصب شده',
	'info_bio' => 'زندگي‌نامه',
	'info_cache_desactive' => 'حفاظه پنهان موقتاً غيرفعال است.',
	'info_chapeau' => 'سر متن',
	'info_chapeau_2' => ':سر متن',
	'info_chemin_acces_1' => 'گزینش: <b>مسير ورود به راهنما</b>',
	'info_chemin_acces_2' => 'شما بايد پس از اين مسير دسترسى به اطلاعات را در راهنما تنظيم كنيد. اين اطلاعات براى شناسائى كاربرانى كه در راهنما هستند ضرورى ميباشد',
	'info_chemin_acces_annuaire' => 'گزینش : <b>مسير ورود به راهنما',
	'info_choix_base' => ': سومين مرحله',
	'info_classement_1' => '<sup>ين</sup>در @liste@',
	'info_classement_2' => '<sup>ين</sup>در@liste@',
	'info_code_acces' => '! كد ها ى وردي تان را فراموش نكنيد',
	'info_compatibilite_html' => 'نرم اچ.تي.ام.ال براي پيگيري ',
	'info_config_suivi' => 'اگر اين آدرس به فهرست ايميل ها mailing-list مربوط ميشود, ميتوانيد در زير آدرسى را كه شركت كنندگان سايت ميتوانند در آن ثبت نام كنند را مشخص كنيد. اين آدرس ميتواند يك  URL( مانند صفحه ثبت نام در فهرست) و يا ميتواند بدين صورت باشد : <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => ' شما ميتوانيد بطور خودكار بوسيله ايميل خبرهاى مربوط به فعاليت تحريريه سايت را دريافت كنيد. براى اين منظور شما بايد در فهرست ايميلها mailing-list ثبت نام كنيد.',
	'info_confirmer_passe' => ':كلمه ورودى جديدتان را تأئيد كنيد',
	'info_conflit_edition_avis_non_sauvegarde' => 'توجه: ميدان‌هاي بعدي از جاهاي ديگر اصلاح شده است. در نتيجه اصلاحات شما ثبت نشده است. ',
	'info_conflit_edition_differences' => 'تفاوت‌ها:',
	'info_conflit_edition_version_enregistree' => 'نسخه ثبت شده:',
	'info_conflit_edition_votre_version' => 'نسخه شما:',
	'info_connexion_base' => '<b>آزمايش ارتباط با پايگاه</b>',
	'info_connexion_base_donnee' => 'اتصال با پايگاه داده‌هاي شما',
	'info_connexion_ldap_ok' => '<b>ارتباط ال.دي.اي.پي موفقيت آميز است.</b><p> مي‌توانيد به مرحله بعد برويد.</p>',
	'info_connexion_mysql' => 'ارتباط شما با SQL',
	'info_connexion_ok' => '.ارتباط برقرار شد',
	'info_contact' => 'تماس',
	'info_contenu_articles' => 'محتوى مقاله ها',
	'info_contributions' => 'مشاركت‌ها',
	'info_creation_paragraphe' => 'براى درست كردن پاراگراف، كافيست كه خط  خالى ايجاد كنيد.',
	'info_creation_rubrique' => 'پيش از نوشتن مقاله ,<br />شما بايد دست كم يك بخش درست كنيد <br />',
	'info_creation_tables' => '<b>درست كردن جداول پايگاه</b>',
	'info_creer_base' => 'يك داده پى جديد <b>بسازيد</b>:',
	'info_dans_rubrique' => ':درون بخش',
	'info_date_publication_anterieure' => 'تاريخ نگارش قبلى :',
	'info_date_referencement' => ': تاريخ پيوند اين سايت',
	'info_derniere_etape' => 'پايان !',
	'info_descriptif' => ':توصيف',
	'info_desinstaller_plugin' => 'داده ها را حذف و plugin را غیر فعال کنید',
	'info_discussion_cours' => 'در حال بحث',
	'info_ecrire_article' => 'پيش از نوشتن مقاله، شما ميبايد دست كم يك بخش درست كنيد.',
	'info_email_envoi' => 'آدرس ايميل برای ارسال (اختياری)',
	'info_email_envoi_txt' => 'آدرس مورد استفاده تان را برای ارسال ايميل در اينجا درج کنيد  (وگرنه از آدرس گيرنده استفاده خواهد شد)',
	'info_email_webmestre' => 'آدرس ايميل وب مستر ',
	'info_envoi_email_automatique' => 'ارسال نامه ها بطور خودكار',
	'info_envoyer_maintenant' => 'الان بفرستيد',
	'info_etape_suivante' => 'به مرحله بعدى برويد',
	'info_etape_suivante_1' => 'شما ميتوانيد به مرحله بعدى برويد',
	'info_etape_suivante_2' => 'شما ميتوانيد به مرحله بعدى برويد',
	'info_exceptions_proxy' => 'استثناءها براي پراكسي',
	'info_exportation_base' => 'صدور پايگاه به@archive@',
	'info_facilite_suivi_activite' => 'براى آسان شدن مداوم فعاليت تحريريه، سيستم  ميتواند براى مثال، خبر درخواستهاى انتشار و اعتبار مقالات را به فهرست پيكهاى نويسند گان بفرستد',
	'info_fichiers_authent' => 'فايل هاى تأئيدى« .htpasswd »',
	'info_forums_abo_invites' => 'سايتتان داراى سخنگاه براى مشتركين ميباشد: از بازديد كنندگان دعوت ميشود كه در قسمت همگانى سايت ثبت نام  كنند.',
	'info_gauche_admin_tech' => '<b>اين صفحه فقط براى مسئولان سايت قابل دسترسى ميباشد.</b><p>  ورود به آن اجازه دسترسى به كاركردهاى گوناگون تعمير ونگهدارى فنى را ميدهد. از جمله روند باز شناسى و تأئيد ويژه اى كه لازمه اش داشتن حق ورود به تارنما است (FTP)',
	'info_gauche_admin_vider' => '<b>اين صفحه فقط براى مسئولان سايت قابل دسترسى ميباشد.</b><p>  ورود به آن اجازه دسترسى به كاركرهاى گوناگون تعمير ونگهداى فنى را ميدهد. از جمله روند باز شناسى و تأئيد ويژه اى كه لازمه اش داشتن حق ورود به تارنما است (FTP)',
	'info_gauche_auteurs' => 'شما نام تمام نگارند گان را در اينجا خواهيد يافت. نوع مسئوليتشان با رنگهاى ايكونها مشخص شده است (نگارنده=آيكون سبز، گردانند سايت=آيكون زرد )',
	'info_gauche_auteurs_exterieurs' => 'نويسندگان بازديدكننده، بدون دسترسي به سايت، با علامت آبي مشخص شده‌اند؛ نويسندگان حذف شده با علامت خاكتسري. ',
	'info_gauche_messagerie' => 'پيام گير بشما اجازه رد و بدل پيام را با ديگر نويسند گان، نگهدارى يادداشتها (براى استفاده شخصى ) همچنين اعلان خبر در صفحه پذيرش را (در صورتى كه از گردانند گان سايت باشيد )ميدهد.',
	'info_gauche_statistiques_referers' => 'اين صفحه, فهرست سايتهاى مرجع را ارائه ميدهد، بعبارتى سايتهايى كه داراى پيوند با سايت شما هستند، (فقط براى ديروز و امروز) : در واقع اين فهرست هر ٢٤ ساعت يكبار نو ميشود',
	'info_gauche_visiteurs_enregistres' => 'شما, در اينجا, همه بازديد كنند گان ثبت شده در قسمت همگانى را خواهيد يافت  (براى مشتركين).',
	'info_generation_miniatures_images' => 'ساخت تصاوير كوچك شده',
	'info_gerer_trad_objets' => '@objets@ :مديريت پيوند‌هاي ترجمه',
	'info_hebergeur_desactiver_envoi_email' => 'تعدادى از ميزبانان ارسال خودكار نامه ها را از سرورهايشان غير فعال ميكنند. در اين صورت،  عملكردهاى بعدى اسپيپ  كار نخوهند كرد. ',
	'info_hier' => ': ديروز',
	'info_identification_publique' => '...شناسنامه شما',
	'info_image_process' => 'خواهشمند است بهترين شيوه ساخت تصاوير كوچك را با كليك كردن بروي تصوير مربوطه انتخاب نماييد.',
	'info_image_process2' => '<<b>N.B.</b> درصورتيكه تصويرى ظاهر نشود, سرورى كه سايتتان را پذيراست براى چنين ابزارى پيكربندى نشده است. اگر مايل به استفاده از اين كاركردها هستيد با سرپرست فنى تماس بگيريد و تقاضاىGD  يا   «Imagick» را بكنيد.',
	'info_images_auto' => 'تصاوير بطور خودكار محاسبه شده اند',
	'info_informations_personnelles' => 'اطلاعات شخصى',
	'info_inscription' => 'ثبت شده در ',
	'info_inscription_automatique' => 'ثبت نام خوكار نويسند گان جديد',
	'info_jeu_caractere' => 'انتخاب نوع و شكل حروف سايت',
	'info_jours' => 'روز',
	'info_laisser_champs_vides' => 'اين قسمتها را خالى بگذاريد)',
	'info_langues' => 'زبانهاى سايت',
	'info_ldap_ok' => 'گواهى درستى LDAP مستقر شده',
	'info_lien_hypertexte' => ': پيوند هايپرتكست',
	'info_liste_nouveautes_envoyee' => 'فهرست تازه‌ها ارسال شده است',
	'info_liste_redacteurs_connectes' => 'فهرست نويسنده گان روى خط',
	'info_login_existant' => '.موجود ميباشد login اين',
	'info_login_trop_court' => 'بيش از اندازه كوتاه Login .',
	'info_login_trop_court_car_pluriel' => 'لاگين بايد دست كم @nb@ كاراكتر داشته باشد.',
	'info_logos' => 'لوگوها',
	'info_maximum' => ': حداكثر',
	'info_meme_rubrique' => 'در همان بخش',
	'info_message_en_redaction' => 'پيام هايتان در حال نگارش',
	'info_message_technique' => ':پيام فنى',
	'info_messagerie_interne' => 'پيام گير داخلى',
	'info_mise_a_niveau_base' => 'تراز گذارى پايگاه SQL',
	'info_mise_a_niveau_base_2' => '{{!توجه}}شما نسخه { قديمى} اسپيپ را نصب كرده ايد براى داده پى هايتان خطر  از بين رفتن وجود دارد و همچنين از كار افتاد گى سايتتان   .<br />{{فايلهاى اسپيپ را دوباره نصب كنيد}}',
	'info_modification_enregistree' => 'تغييرها ثبت شد',
	'info_modifier_auteur' => 'اصلاح نويسنده',
	'info_modifier_rubrique' => ':اصلاح بخش ',
	'info_modifier_titre' => '@titre@ : اصلاح       ',
	'info_mon_site_spip' => 'SPIP سايت من',
	'info_moyenne' => ': متوسط',
	'info_multi_cet_article' => ' زبان اين مقاله :',
	'info_multi_langues_choisies' => 'خواهشمند است كه زبانهاى موجود براى نويسند گان سايتتان را در زير انتخاب كنيد. زبانهاى از پيش استفاده شده نميتوانند غير فعال شوند.',
	'info_multi_objets' => '@objets@ :فعال‌سازي منوي زبان',
	'info_multi_secteurs' => '...تنها براى بخشهاى واقع در ريشه؟',
	'info_nb_articles' => '@nb@ مقاله',
	'info_nb_auteurs' => '@nb@ نويسنده',
	'info_nb_messages' => '@nb@ پيام',
	'info_nb_mots_cles' => '@nb@ كليدواژه',
	'info_nb_rubriques' => '@nb@ بخش',
	'info_nb_visiteurs' => '@nb@ بازديد‌كننده',
	'info_nom' => 'نام',
	'info_nom_destinataire' => 'نام گيرنده',
	'info_nom_pas_conforme' => 'تگ‌هاي اچ.تي.ام.ال مجاز نيستند',
	'info_nom_site' => 'نام سايتتان',
	'info_nombre_articles' => 'مقاله @nb_articles@ ',
	'info_nombre_rubriques' => 'بخش @nb_rubriques@ ',
	'info_nombre_sites' => 'سايت @nb_sites@',
	'info_non_deplacer' => '...جابجا نكنيد',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'اسپيپ ميتواند بطور منظم اخبار تازه هاى سايت را مانند مقاله ها، مقاله هاى كوتاه تازه منتشر شده و... را بفرستد ',
	'info_non_envoi_liste_nouveautes' => 'فهرست تازه ها را نفرستيد',
	'info_non_modifiable' => 'نميتواند اصلاح شود',
	'info_non_suppression_mot_cle' => 'نميخواهم اين كليد-واژه را حذف كنم',
	'info_notes' => 'يادداشت ',
	'info_nouvel_article' => 'مقاله جديد',
	'info_nouvelle_traduction' => 'برگردان جديد',
	'info_numero_article' => ': مقاله شماره',
	'info_obligatoire_02' => '(اجباري)',
	'info_option_accepter_visiteurs' => 'پذيرفتن ثبت نام بازديد كنندگان سايت همگانى',
	'info_option_ne_pas_accepter_visiteurs' => 'رد ثبت نام بازديدكنندگان',
	'info_options_avancees' => 'گزينش هاى پيشرفته',
	'info_ou' => '...يا',
	'info_page_interdite' => 'صفحه ممنوع',
	'info_par_nom' => 'توسط نام',
	'info_par_nombre_article' => 'توسط شمار مقالها',
	'info_par_statut' => 'توسط نوع',
	'info_par_tri' => '’(بترتيب@tri@)’',
	'info_passe_trop_court' => 'كلمه ورود خيلى كوتاه',
	'info_passe_trop_court_car_pluriel' => 'گذرواژه‌ دست كم بايد @nb@ كاراكتر داشته باشد.',
	'info_passes_identiques' => 'دو كلمه ورود با هم يكسان نيستند',
	'info_plus_cinq_car' => 'بيش از پنج حرف',
	'info_plus_cinq_car_2' => '(بيش از پنج حرف)',
	'info_plus_trois_car' => '(بيش از سه حرف)',
	'info_popularite' => '@popularite@ : محبوبيت@visites@ : بازديد',
	'info_post_scriptum' => 'نوشتار پس از متن اصلى',
	'info_post_scriptum_2' => ':نوشتار پس از متن اصلى',
	'info_pour' => 'براى',
	'info_preview_texte' => 'اين امكان وجود دارد كه سايت را پيش از آماده شدن (پيش از پيشنهاد مقالات) بازبينى كرد مانند زمانيكه همه ى مقالات و اخبار منتشر شده اند.اين امكان ميتواند تنها براى گردانند گان سايت يا نويسندگان يا براى هيچكس نباشد.', # MODIF
	'info_procedez_par_etape' => 'مرحله به مرحله اقدام كنيد',
	'info_procedure_maj_version' => 'روند به روز كردن بايد به جريان بيفتد تا داده پى ها بتوانند با نسخه جديد منطبق شوند.',
	'info_proxy_ok' => 'آزمایش پروکسی با موفقیت انجام شد.',
	'info_ps' => 'P.-S.',
	'info_publier' => 'منتشر کنید',
	'info_publies' => 'مقاله هاى منتشر شده تان روى تارنما',
	'info_question_accepter_visiteurs' => 'اگر اسكلت سايتتان ثبت شمار بازديدكنندگان  را بى آنكه اجازه ى ورود به قسمت خصوصى سايت را داشته باشند را  داراست خواهشمند است گزينه ى زير را فعال كنيد:',
	'info_question_inscription_nouveaux_redacteurs' => 'آيا ثبت نام نويسند گان جديد را از سايت همگانى قبول ميكنيد؟ اگر ميكنيد، كاربران ميتوانند با پر كردن يك پرسشنامه ثبت نام كنند و به محوطه خصوصى راه يابند. آنها ميتوانند مقالاتشان را مطرح كنند <blockquote><i>در هنگام ثبت نام كاربران يك ايميل دريافت خواهند كرد كه شامل كد ورودي شان به سايت خصوصى خواهد بود. تعدادى از ميزبانان، ارسال ايميل را از سرورها غير فعال كرده اند: دراينصورت ثبت نام خودكار غير ممكن خواهد بود..</i></blockquote>',
	'info_qui_edite' => '@nom_auteur_modif@ روي اين مطلب @date_diff@ كار كرده است.',
	'info_racine_site' => 'ريشه سايت',
	'info_recharger_page' => 'خواهشمند است اين صفحه را تا چند لحظه بعد دوباره شارژ كنيد',
	'info_recherche_auteur_zero' => '"@cherche_auteur@" : جستجوى بدون نتيجه براى',
	'info_recommencer' => '.خواهشمند است دوباره شروع كنيد',
	'info_redacteur_1' => 'نويسنده',
	'info_redacteur_2' => 'به بخش خصوصى دسترسى دارد(<i>توصيه ميشود</i>)',
	'info_redacteurs' => 'نويسندگان',
	'info_redaction_en_cours' => 'در حال نگارش',
	'info_redirection' => 'هدايت دوباره آدرس ',
	'info_redirection_activee' => 'باز سو دهي فعال است. ',
	'info_redirection_desactivee' => 'باز سو دهي حذف شده. ',
	'info_refuses' => 'مقاله هايتان كه پذيرفته نشده اند',
	'info_reglage_ldap' => ' گزينش :<b> تنظيم ورود LDAP</b>',
	'info_renvoi_article' => 'تغییر محل. اين مقاله به این صفحه برمیگردد:',
	'info_reserve_admin' => 'تنها گردانندگان سايت حق اصلاح اين آدرس را دارند',
	'info_restreindre_rubrique' => ':محدوديت در اداره بخش',
	'info_resultat_recherche' => ':نتيجه جستجو',
	'info_rubriques' => 'بخش ها',
	'info_rubriques_02' => 'بخش ها',
	'info_rubriques_trouvees' => 'بخش هاى پيدا شده',
	'info_sans_titre' => 'بدون عنوان',
	'info_selection_chemin_acces' => '<b>انتخاب كنيد</b> راه ورودى را در راهنما',
	'info_signatures' => 'امضاء',
	'info_site' => 'سايت',
	'info_site_2' => ':سايت',
	'info_site_min' => 'سايت',
	'info_site_reference_2' => 'سايت مرجع',
	'info_site_web' => 'وب سايت:',
	'info_sites' => 'سايت',
	'info_sites_lies_mot' => 'سايتهاى پيوندى مربوط به اين واژه-كليد',
	'info_sites_proxy' => 'از پروكسى استفاده كنيد',
	'info_sites_trouves' => 'سايت هاى پيدا شده',
	'info_sous_titre' => ':عنوان فرعى',
	'info_statut_administrateur' => 'گرداننده سايت',
	'info_statut_auteur' => 'وضعيت اين نويسنده:',
	'info_statut_auteur_2' => 'من هستم',
	'info_statut_auteur_a_confirmer' => 'ثبت نام تائید شود',
	'info_statut_auteur_autre' => 'وضعیت دیگر:',
	'info_statut_redacteur' => 'نويسنده',
	'info_statut_utilisateurs_1' => 'وضعيت كاربران ورودى',
	'info_statut_utilisateurs_2' => 'وضعيت اشخاص حاضر در راهنماى ال دى ا پى را كه براى اولين بار به سايت ميپيوندند مشخص كنيد. شما ميتوانيد پس از آن  براى هر نويسنده آنرا مورد به مورد اصلاح كنيد',
	'info_suivi_activite' => 'دنباله سر مقاله',
	'info_surtitre' => ':سر عنوان',
	'info_syndication_integrale_1' => 'سایتتان فایلهای syndication را پیشنهاد میکند (voir « <a href="@url@">@titre@</a> »). ',
	'info_syndication_integrale_2' => 'آیا مایلید که مقاله ها را بطور کامل یا فقط خلاصه ای از آنها را بفرستید؟',
	'info_table_prefix' => 'شما میتوانید پیشوند نام جدولهای داده ها را اصلاح کنید زیرا هنگامیکه از یک داده پی برای چند سایت استفاده میکنید اینکار اجباری است. پیشوند باید با حروف کوچک بدون اکسان و بی فاصله باشد.',
	'info_taille_maximale_images' => 'اسپيپ برش‌ بالاتر تصاوير را كه مي‌تواند نشان دهد(در ميليون‌ها پيكشل) آزمايش مي‌كند. <br /> تصاوير بزرگتر كاهش نمي‌يابند.',
	'info_taille_maximale_vignette' => 'حد اكثر اندازه براى توليد تصاوير كوچك توسط سيستم',
	'info_terminer_installation' => 'شما اكنون ميتوانيد روند استقرار برنامه را پايان دهيد.',
	'info_texte' => 'متن',
	'info_texte_explicatif' => 'متن توضيحى',
	'info_texte_long' => 'متن بيش از اندازه بلند ميباشد : در ابتدا به چند قسمت تقسيم و پس از تائيد، قطعات به هم متصل خواهند شد.',
	'info_texte_message' => 'متن پيام شما',
	'info_texte_message_02' => 'متن پيام',
	'info_titre' => ':عنوان',
	'info_total' => ':كل',
	'info_tous_articles_en_redaction' => 'تمام مقالات در حال نگارش',
	'info_tous_articles_presents' => 'تمام مقالات منتشر شده در اين بخش',
	'info_tous_articles_refuses' => 'تمام مقالات رد شده',
	'info_tous_les' => 'تمام :',
	'info_tout_site' => 'همه سايت',
	'info_tout_site2' => 'مقاله به اين زبان ترجمه نشده.',
	'info_tout_site3' => 'مقاله به اين زبان ترجمه شده,  سپس تغييراتى در مقاله ى اصلى صورت گرفته, بدين جهت بايد برگردان آنرا بروز كرد.',
	'info_tout_site4' => 'مقاله به اين زبان ترجمه و برگردان آن بروز شده.',
	'info_tout_site5' => 'مقاله ى اصلى',
	'info_tout_site6' => ' :<b>توجه<b/> تنها مقالات اصلى اعلان ميشوند و برگردانهايشان با رنگهايى كه گوياى وضعيت آنهاست به آنها متصلند.',
	'info_traductions' => 'ترجمه‌ها',
	'info_travail_colaboratif' => 'مقالات حاصل كار دست جمعى',
	'info_un_article' => 'يك مقاله',
	'info_un_site' => ',يك سايت',
	'info_une_rubrique' => ',يك بخش',
	'info_une_rubrique_02' => '١ بخش',
	'info_url' => ':URL',
	'info_url_proxy' => 'پراكسي URL',
	'info_url_site_pas_conforme' => 'يو.آر.ال سايت معتبر نيست. ',
	'info_url_test_proxy' => 'تست URL',
	'info_urlref' => 'پيوند هايپرتکست:',
	'info_utilisation_spip' => 'شما اكنون ميتوانيد از سيستم انتشار حضورى استفاده كنيد',
	'info_visites_par_mois' => ':نمودار ماهانه',
	'info_visiteur_1' => 'بازديد كننده',
	'info_visiteur_2' => 'سايت همگانى',
	'info_visiteurs' => 'بازديد كنندگان',
	'info_visiteurs_02' => 'بازديد كنندگان سايت همگانى',
	'info_webmestre_forces' => 'وب مستر‌ها در حال حاضر در <  tt>@file_options@</tt تعريف مي‌شوند.',
	'install_adresse_base_hebergeur' => 'آدرس داده ها که توسط میزبان وب اعطا شده',
	'install_connect_ok' => 'پايگاه داده‌هاي جديد اعلام كرده از سرور با نام @connect@استفاده مي‌كند. ',
	'install_echec_annonce' => 'نصب احتمالا موفق آميز نخواهد بود يا به يك سايت غير كاربردى خاتمه ميابد...',
	'install_extension_mbstring' => 'اسپيپ با اين كار نميكند :',
	'install_extension_php_obligatoire' => 'اسپيپ به فايلهاى php نياز دارد:',
	'install_login_base_hebergeur' => 'Login ورودی به سایت که توسط میزبان وب داده شده',
	'install_nom_base_hebergeur' => 'نام پایگاه داده ها که توسط میزبان وب داده شده:',
	'install_pas_table' => 'پايگاه عملاً بدون جدول‌ها',
	'install_pass_base_hebergeur' => 'کد ورودی به سایت که توسط میزبان وب داده شده',
	'install_php_version' => 'نسخه @version@ PHP ناکافیست  دستکم= @minimum@',
	'install_select_langue' => 'يك زبان را انتخاب كنيد سپس روى دكمه "بعدى" كليك كنيد، روند استقرار برنامه بكار خواهد افتاد',
	'install_select_type_db' => 'نوع پايگاه داده‌ها را تعيين كردن',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Serveur de base de données attribué par l’hébergeur ',
	'install_table_prefix_hebergeur' => 'پیشوند جدولها که توسط میزبان وب داده شده:',
	'install_tables_base' => 'جدول‌هاي پايگاه',
	'install_types_db_connus' => 'اسپيپ مي‌تواند<b>MySQL</b> (رايج‌تر)و <b>SQLite</b> را استفاده كند.',
	'install_types_db_connus_avertissement' => 'حمايت از <b>PostgreSQL</b> عملاً به صورت تجربي پيشنهاد شده است.',
	'instituer_erreur_statut_a_change' => 'وضعيت همين الأن اصلاح شده',
	'instituer_erreur_statut_non_autorise' => 'نمي‌توانيد اين وضعيت را انتخاب كنيد',
	'intem_redacteur' => 'نويسنده',
	'intitule_licence' => 'مجوز',
	'item_accepter_inscriptions' => 'ثبت نامها را بپذيريد',
	'item_activer_messages_avertissement' => 'پيامهاى اخطار را فعال كنيد',
	'item_administrateur_2' => 'گرداننده سايت',
	'item_afficher_calendrier' => 'در بخش تقويم نمايش دهيد',
	'item_autoriser_syndication_integrale' => 'پخش کامل مقاله ها در فایل های syndication',
	'item_choix_administrateurs' => 'گردانندگان سايت',
	'item_choix_generation_miniature' => '.تصاوير كوچك را بطور خودكار بسازيد',
	'item_choix_non_generation_miniature' => '.تصاوير كوچك را بطور خودكار نسازيد',
	'item_choix_redacteurs' => 'نويسندگان',
	'item_choix_visiteurs' => 'بازديد كنندگان سايت همگانى',
	'item_creer_fichiers_authent' => '.htpasswd : از اين فايلها بسازيد',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'فعال سازي سامانه‌ي پيام‌دهي و تقويم',
	'item_mots_cles_association_articles' => 'به مقالات',
	'item_mots_cles_association_rubriques' => 'به بخشها ',
	'item_mots_cles_association_sites' => 'به سايتهاى مرجع يا پيوندى',
	'item_non' => 'خير',
	'item_non_accepter_inscriptions' => 'ثبت نامها را نپذيريد',
	'item_non_activer_messages_avertissement' => 'بدون پيام اخطار',
	'item_non_afficher_calendrier' => 'در تقويم نيايد',
	'item_non_autoriser_syndication_integrale' => 'تنها خلاصه ی آنرا منتشر کنید',
	'item_non_creer_fichiers_authent' => 'اين فايلها را درست نكنيد',
	'item_non_messagerie_agenda' => 'غيرفعال سازي سامانه‌ي پيام‌دهي و تقويم',
	'item_non_publier_articles' => 'مقالات را پيش از تعيين تاريخ قطعى انتشار منتشر نكنيد',
	'item_nouvel_auteur' => 'نويسنده جديد',
	'item_nouvelle_rubrique' => 'بخش جديد',
	'item_oui' => 'آرى',
	'item_publier_articles' => '.مقالات را عليرغم تاريخ نشرشان منتشر كنيد',
	'item_reponse_article' => 'پاسخ به مقاله',
	'item_version_html_max_html4' => 'در سايت همگاني فقط اچ.تي.ام.ال4 را استفاده كنيد',
	'item_version_html_max_html5' => 'اجازه‌ي اج.تي.ام.ال5',
	'item_visiteur' => 'بازديد كننده',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'ميل ابزار ',
	'label_bando_outils_afficher' => 'نمايش ابزارها',
	'label_bando_outils_masquer' => 'پوشاندن ابزارها',
	'label_choix_langue' => 'زبان خود را انتخاب كنيد',
	'label_nom_fichier_connect' => 'اعلام نام مورد استفاده براي اين سرور ',
	'label_slogan_site' => 'شعار سايت',
	'label_taille_ecran' => 'پهناي پرده‌ي نمايش', # MODIF
	'label_texte_et_icones_navigation' => 'منوي ناوبري ',
	'label_texte_et_icones_page' => 'صفحه‌ي نمايش ',
	'ldap_correspondance' => 'ميدان موروثي @champ@',
	'ldap_correspondance_1' => 'ميدان‌هاي موروثي LDAP',
	'ldap_correspondance_2' => 'براي هر يك از ميدان‌هاي بعدي اسپيپ، نام متناسب با ميدان LDAP را وارد كنيد. اگر نمي‌خواهيد پر كنيد آن را خالي بگذاريد، براي پركردن چندين ميدان LDAP  با كاما يا فاصله جداشان كنيد.',
	'lien_ajouter_auteur' => 'نام اين نويسنده را اضافه كنيد',
	'lien_ajouter_une_rubrique' => 'افزودن اين بخش',
	'lien_email' => 'ايميل',
	'lien_nom_site' => ':نام سايت',
	'lien_retirer_auteur' => 'خارج كردن نام نويسنده',
	'lien_retirer_rubrique' => 'حذف كردن بخش',
	'lien_retirer_tous_auteurs' => 'حذف تمام مؤلفان',
	'lien_retirer_toutes_rubriques' => 'حذف تمام بخش‌ها',
	'lien_site' => 'سايت',
	'lien_tout_deplier' => 'همه را باز كنيد',
	'lien_tout_replier' => 'همه را ببنديد',
	'lien_tout_supprimer' => 'همه را حذف کنید',
	'lien_trier_nom' => 'بترتيب نام',
	'lien_trier_nombre_articles' => 'بترتيب تعداد مقالات',
	'lien_trier_statut' => 'بترتيب موقعيت',
	'lien_voir_en_ligne' => 'روى شبكه ببينيد :',
	'logo_article' => 'لوگوي مقاله',
	'logo_auteur' => 'لوگوي نويسنده',
	'logo_rubrique' => 'لوگوي بخش',
	'logo_site' => 'لوگوي اين سايت',
	'logo_standard_rubrique' => 'لوگوي استاندارد بخش‌ها',
	'logo_survol' => 'لوگوي موش‌ روش!',

	// M
	'menu_aide_installation_choix_base' => 'انتخاب پايگاه',
	'module_fichier_langue' => 'فايل زبان',
	'module_raccourci' => 'راه كوتاه',
	'module_texte_affiche' => 'متن اعلانى',
	'module_texte_explicatif' => 'شما ميتوانيد راه هاى كوتاه زير را در اسكلتهاى سايتتان بگنجانيد. آنها بطور خودكار به زبانهايى كه داراى فايل زبان هستند, ترجمه ميشوند.',
	'module_texte_traduction' => 'فايل زبان« @module@ »بصورت زير در دسترس ميباشد:',
	'mois_non_connu' => 'شناخته نشده',

	// N
	'nouvelle_version_spip' => 'اسپيپ نسخه‌ي @version@ در دسترس است  ', # MODIF

	// O
	'onglet_contenu' => 'محتوا',
	'onglet_declarer_une_autre_base' => 'اعلام يك پايگاه ديگر',
	'onglet_discuter' => 'بحث',
	'onglet_interactivite' => 'تعامل',
	'onglet_proprietes' => 'خصوصيات',
	'onglet_repartition_actuelle' => 'در حال حاضر',
	'onglet_sous_rubriques' => 'زيربخش‌ها',

	// P
	'page_pas_proxy' => 'اين صفحه نبايد از طريق پراكسي بگذرد',
	'pas_de_proxy_pour' => 'در صورت لزوم نام ماشینها یا موضوعاتی که باید در برابر این پروکسی بی اثر باشد را مشخص کنید (برای مثال:@مثال@)',
	'plugin_charge_paquet' => 'باربرداري فايل آرشيوي @name@',
	'plugin_charger' => 'بارگذاري ',
	'plugin_erreur_charger' => 'خطا: بارگذاري @zip@ ممكن نيست',
	'plugin_erreur_droit1' => 'نوشتن در ديركتوري <code>@dest@</code> ممكن نيست.',
	'plugin_erreur_droit2' => 'لطفاً مجوز‌هاي نوشتن در اين ديركتوري را چك كنيد (و اگر لازم بود آن را ايجاد كنيد)، در غير اين صورت، فايل‌ها را با اف.تي.پي نصب كنيد. ',
	'plugin_erreur_zip' => 'اشكال pclzip: خطا @status@',
	'plugin_etat_developpement' => 'در حال تکمیل',
	'plugin_etat_experimental' => 'آزمایشی',
	'plugin_etat_stable' => 'ثابت',
	'plugin_etat_test' => 'در حال آزمایش',
	'plugin_impossible_activer' => 'فعال کردن plugin @plugin@ غیر ممکن میباشد',
	'plugin_info_automatique1' => 'اگر مي‌خواهيد نصب خودكار پلاكنين‌ها را مجاز كنيد، لطفاً: ',
	'plugin_info_automatique1_lib' => 'اگر مي‌خواهيد نصب خودكار اين مجموعه‌فايل را مجاز كنيد، لطفاً: ',
	'plugin_info_automatique2' => 'يك ديركتوري <code>@rep@</code> ايجاد كنيد؛',
	'plugin_info_automatique3' => 'بررسي كنيد كه سرور مجوز‌ نوشتن در اين ديركتوري را دارد.',
	'plugin_info_automatique_creer' => 'ايجاد در ريشه‌ي سايت.',
	'plugin_info_automatique_exemples' => 'نمونه‌ها:',
	'plugin_info_automatique_ftp' => 'مي‌توانيد پلاگين‌ها را با FTP در ديركتوري  <tt>@rep@</tt> نصب كنيد',
	'plugin_info_automatique_lib' => 'بعضي پلاگين‌ها لازم است بتوانند فايل‌ها را در ديركتوري <code>lib/</code> بارگذاري كنند. در اين صورت، اين ديركتوري بايد در ريشه‌ي سايت ايجاد شود.  ',
	'plugin_info_automatique_liste' => 'فهرست‌هاي پلاگين‌هايتان: ',
	'plugin_info_automatique_liste_officielle' => 'پلاگين‌هاي رسمي',
	'plugin_info_automatique_liste_update' => 'روزآمدسازي فهرست‌ها',
	'plugin_info_automatique_ou' => 'يا...',
	'plugin_info_automatique_select' => 'يكي از پلاگين‌هاي زير را انتخاب كنيد: اسپيپ آن را در ديركتوري <code>@rep@</code> بارگذاري مي‌كند؛ اگر آن پلاگين آنجا باشد آن را به روز مي‌كند.',
	'plugin_info_credit' => 'معتبر',
	'plugin_info_erreur_xml' => 'اعلام پلاگين علط',
	'plugin_info_install_ok' => 'نصب موفق',
	'plugin_info_necessite' => 'الزام‌ها:‌',
	'plugin_info_non_compatible_spip' => 'اين پلاگن با اين نسخه‌ي اسپيپ نمي‌خواند',
	'plugin_info_plugins_dist_1' => 'پلاگين‌هاي زير در پوشه‌ي @plugins_dist@ بارگذاري و فعال‌ شده‌اند. ',
	'plugin_info_plugins_dist_2' => 'غيرفعال نمي‌شوند',
	'plugin_info_telecharger' => 'باربرداري از @url@ و نصب در @rep@',
	'plugin_info_upgrade_ok' => ' روزآمدسازي موفق',
	'plugin_librairies_installees' => 'آرشيو‌هاي نصب‌ شده',
	'plugin_necessite_lib' => 'اين پلاگين به آرشيو @lib@ نياز دارد',
	'plugin_necessite_plugin' => 'به plugin @plugin@ نسخه ی @version@ نیاز دارید', # MODIF
	'plugin_necessite_plugin_sans_version' => 'پلاگين @plugin@ لازم است ',
	'plugin_necessite_spip' => 'به اسپیپ نسخه ی @version@ نیاز دارید.',
	'plugin_source' => 'منبع: ',
	'plugin_titre_automatique' => 'نصب خودكار ',
	'plugin_titre_automatique_ajouter' => 'افرودن پلاگين‌ها',
	'plugin_titre_installation' => 'نصب پلاگين  @plugin@',
	'plugin_titre_modifier' => 'پلاگين‌هاي من ',
	'plugin_zip_active' => 'براي فعال سازي ادامه دهيد',
	'plugin_zip_adresse' => 'در زير، نشاني فايل زيپ پلاگين يا نشاني فهرست پلاگين‌ها را مشخص كنيد تا بارگذاري شود',
	'plugin_zip_adresse_champ' => 'نشاني پلاگين يا فهرست',
	'plugin_zip_content' => 'شامل فايل‌هاي (@taille@) آماده براي بازگذاري در ديركتوري <code>@rep@</code> ',
	'plugin_zip_installe_finie' => 'فايل @zip@ باز و نصب شده است.',
	'plugin_zip_installe_rep_finie' => 'فايل @zip@ باز و در ديركتوري @zip@ نصب شده است',
	'plugin_zip_installer' => 'اكنون مي‌توانيد نصبش كنيد.',
	'plugin_zip_telecharge' => 'فايل @zip@ بارگذاري شده',
	'plugins_actif_aucun' => 'هيچ پلاگيني فعال نيست.',
	'plugins_actif_un' => 'يك پلاگين فعال است. ',
	'plugins_actifs' => ' @count@ پلاگين فعال است.',
	'plugins_actifs_liste' => 'فعال‌سازي شده',
	'plugins_compte' => '@count@ پلاگين ',
	'plugins_disponible_un' => 'يك پلاگين در دصترس.',
	'plugins_disponibles' => '@count@ پلاگين در دسترس.',
	'plugins_erreur' => 'خطا در پلاگين‌ها: @plugins@',
	'plugins_liste' => 'فهرست plugins',
	'plugins_liste_dist' => 'پلاگين‌هاي قفل شده ',
	'plugins_recents' => 'پلاگين‌هاي اخير.',
	'plugins_tous_liste' => 'همه',
	'plugins_vue_hierarchie' => 'سلسله مراتب ',
	'plugins_vue_liste' => 'فهرست',
	'protocole_ldap' => 'نسخه ی پروتکل:',

	// Q
	'queue_executer_maintenant' => 'اجرا حالا',
	'queue_info_purger' => 'مي‌‌توانيد تمام كارهاي در دست انجام را حذف كنيد و فهرست  كارهاي دوره‌اي را بازتنظيم (ريست) كنيد', # MODIF
	'queue_nb_jobs_in_queue' => '@nb@ وظيفه در صف ',
	'queue_next_job_in_nb_sec' => 'وظيفه‌ي بعدي در  @nb@ امين',
	'queue_no_job_in_queue' => 'وظيفه‌اي در دست اجرا نيست',
	'queue_one_job_in_queue' => '1 وظيفه در صف',
	'queue_purger_queue' => 'بازتنظيم فهرست كارها',
	'queue_titre' => 'فهرست وظيفه‌ها',

	// R
	'repertoire_plugins' => 'رپرتوار:',
	'required' => '(اجباري)',

	// S
	'sans_heure' => 'زمان نامشخص',
	'statut_admin_restreint' => 'ادمين محدود',
	'statut_webmestre' => 'وب مستر ',

	// T
	'tache_cron_asap' => 'وظيفه‌ي CRON @function@ (ASAP)', # MODIF
	'tache_cron_secondes' => 'وظيفه‌ي CRON @function@ (تمام @nb@)', # MODIF
	'taille_cache_image' => 'اندازه ى تصاوير, كه توسط اسپيپ حساب شده ( تصاوير كوچك اسناد, عناوين گرافيكى عرضه شده, كاربردهاى رياضى با فرمهاى TeX...) در رپرتوار @dir@جمعا @taille@ را اشغال ميكنند.',
	'taille_cache_infinie' => 'اين سايت محدوديت اندازه ى رپرتوار Cache را پيش بينى نميكند.',
	'taille_cache_maxi' => 'اسپيپ سعى در محدود كردن اندازه ى رپرتوار Cache به اين اندازه دارد <b>@octets@</b>.',
	'taille_cache_moins_de' => 'اندازه‌ي حافظه‌ي پنهان كمتر از@octets@ است.',
	'taille_cache_octets' => ' اندازه ى فايل پنهان در حال حاضر تقريبا @octets@ است.  ',
	'taille_cache_vide' => 'فايل پنهان خالى است.',
	'taille_repertoire_cache' => 'اندازه ى فايل پنهان',
	'text_article_propose_publication' => ' مقاله‌ى پيشنهادى براى انتشار.',
	'texte_acces_ldap_anonyme_1' => 'تعدادى از سرورهاى ال دى اپى ورود بدون نام را نميپذيرند. در اينصورت شما بايد يك نام شناسايى را مشخص كنيد تا بتوانيد به اطلاعات راهنما دسترسى داشته باشيد. در بيشتر موارد ميادين بعدى را ميتوان خالى گذاشت.',
	'texte_admin_effacer_01' => 'اين فرمان محتوى داده پى ها، همچنين دسترسى نويسندگان و گردانندگان به سايت را كاملأ پاك خواهد كرد، در صورت اجراى آن شما بايد اسپيپ را دوباره نصب كنيد تا بتوانيد پايگاه جديدى همراه با حق استفاده براى گردانندگان را داشته باشيد.',
	'texte_adresse_annuaire_1' => 'اگر راهنماتان در همان رايانه اى نصب شده كه سايت تارنما، احتمالا مربوط است به :«localhost» ',
	'texte_ajout_auteur' => 'نام نويسنده بعدى به مقاله اضافه شد :',
	'texte_annuaire_ldap_1' => 'اگر شما به راهنماى ال دى ا پى دسترسى داريد، ميتوانيد بطور خودكار كاربران را به اسپيپ اضافه كنيد',
	'texte_article_statut' => 'اين مقاله :',
	'texte_article_virtuel' => 'مقاله مجازى',
	'texte_article_virtuel_reference' => ' <b>مقاله مجازى :</b> مقاله پيوندى شما در سايت اسپيپ است، اما شما ميتوانيد آنرا به آدرس ديگرى هدايت كنيد.براى اينكار بايد آدرس زيرى را حذف كنيد (URL)',
	'texte_aucun_resultat_auteur' => 'جستجوى بى نتيجه براى"@cherche_auteur@"',
	'texte_auteur_messagerie' => ' اين سايت ميتواند ليست نويسندگان متصل به سايت را بطور دائم نشان دهد اين بشما امكان رد و بدل كردن پيام را بطور مستقيم ميدهد. شما همچنين ميتوانيد گزينش «نامرئي» را انتخاب كنيد',
	'texte_auteurs' => 'نويسندگان',
	'texte_choix_base_1' => 'پايگاه تان را انتخاب كنيد :',
	'texte_choix_base_2' => 'سرور اس كيوال حاوى چند داده پى است.',
	'texte_choix_base_3' => 'پايگاهى را كه توسط ميزبانتان بشما داده شده <b>انتخاب كنيد</b>:',
	'texte_choix_table_prefix' => 'پیشوند جدولها:',
	'texte_compatibilite_html' => 'مي‌توانيد از اسپيپ بخواهيد تا، روي سايت همگاني، كد سازگار با نرم <i>HTML4</i>  ايجاد كند، يا به اسپيپ اجازه دهيد تا از از امكانات مدرن‌تر <i>HTML5</i> استفاده كند. ',
	'texte_compatibilite_html_attention' => 'در فعال‌سازي گزينه‌ي <i>HTML5</i> هيچ خطري وجود ندارد، اما در آن صورت، صفحه‌هاي سايت شما بايد با كد: <code>&lt;!DOCTYPE html&gt;</code> شروع شوند تا معتبر باشند. ',
	'texte_compte_element' => 'عنصر @count@ ',
	'texte_compte_elements' => ' @count@ عنصر',
	'texte_conflit_edition_correction' => 'لطفاً تفاوت‌هاي دو متن زير را چك كنيد؛ نيز مي‌توانيد اصلاحات خود را روبرداري كرده و سپس از نو شروع كنيد.',
	'texte_connexion_mysql' => 'اطلاعات داده شده توسط ميزبانتان را بخوانيد: اين اطلاعات بايد كدهاي ارتباطي با سرور ماي‌اسكيو‌ال شما را داشته باشد.',
	'texte_contenu_article' => '(محتوى مقاله در چند كلمه)',
	'texte_contenu_articles' => 'بنابر ماكت مورد استفاده سايتتان، شما ميتوانيد تصميم به استفاده تنها تعدادى از اجزاى مقالات را بگيريد. از ليست زير براى انتخاب اجزاى مورد نيازتان استفاده كنيد.',
	'texte_crash_base' => 'اگر داده پى هايتان از بين رفتند، ميتوانيد گزينش ترميم خودكار را آزمايش كنيد',
	'texte_creer_rubrique' => 'پيش از نوشتن مقاله، شما بايد يك بخش بسازيد',
	'texte_date_creation_article' => ' تاريخ نوشتن مقاله',
	'texte_date_creation_objet' => 'تاريخ ايجاد', # on ajoute le &quot;:&quot;
	'texte_date_publication_anterieure' => 'تاريخ نگارش قبلى:',
	'texte_date_publication_anterieure_nonaffichee' => 'تاريخ نگارش قبلى را اعلان نكنيد.',
	'texte_date_publication_article' => 'تاريخ انتشار بروى تارنما:',
	'texte_date_publication_objet' => 'تاريخ نشر وصل‌خط:',
	'texte_descriptif_rapide' => 'توصيف سريع',
	'texte_effacer_base' => 'داده پى هاى اسپيپ را پاك كنيد',
	'texte_effacer_statistiques' => 'حذف آمارها',
	'texte_en_cours_validation' => 'مطالب زير در انتظار تأييد هستند. ',
	'texte_enrichir_mise_a_jour' => 'شما ميتوانيد صفحه بندى متن تان را با بعضى از علائم آراسته كنيد (مانند كروشه، آكولاد،...)',
	'texte_fichier_authent' => '<b>آيا سپيپ بايد فايل‌هاى <tt>.htpasswd</tt>
و <tt>.htpasswd-admin</tt> را در دايركتوري @dossier@ بسازد؟</b><p>
اين فايل‌ها مي‌توانند بشما در محدود كردن دسترسى نويسندگان وگردانندگان سايت در جاهاى ديگر( براى مثال برنامه خارجى آمار) كمك كنند).</p><p>
اگر به اين گزينه نياز نيست، اسپيپ خودبخود آنرا اداره ميكند (بدون  ساخت فايل‌ها)</p>.', # MODIF
	'texte_informations_personnelles_1' => 'اكنون سيستم براى شما دسترسى انحصارى به سايت را درست ميكند.',
	'texte_informations_personnelles_2' => 'تذكر : اگر  نصب دوباره است، اگر دسترسى شما به سايت برقرار است، مي‌توانيد',
	'texte_introductif_article' => '(متن مقدمه اى مقاله.)',
	'texte_jeu_caractere' => 'بشما توصیه میشود برای سایتتان از الفبای جهانی (<tt>utf-8</tt> استفاده کنید زیرا امکان خواندن متنها در تمامی زبانها را میدهد و مشکلی هم برای مرورگرهای جدید پدید نمیآورد. ',
	'texte_jeu_caractere_3' => 'سایت شما اکنون نویسه ها را مستقر کرد.',
	'texte_jeu_caractere_4' => 'اگر این نویسه ها با سایت شما مطابق نیست (برای مثال پس از بازسازی داده پی ها) یا اینکه شما مایل به بکارگیری نویسه های دیگری هستید آنرا در اینجا مشخص کنید:',
	'texte_login_ldap_1' => '(براى ورود بى نام، خالى بگذاريد، يا تمام مسير را درج كنيد، براى مثال« <tt>uid=dupont, ou=users, dc=mon-domaine, dc=com</tt> ».)',
	'texte_login_precaution' => 'توجه ! شما با اين كد متصل شديد. از اين پرسشنامه با احتياط استفاده كنيد.',
	'texte_messagerie_agenda' => 'يك سامانه‌ي پيام‌دهي به نويسندگان سايت امكان مي‌دهد تا در قسمت شخصي به صورت مستقيم با يكديگر ارتباط برقرار كنند. اين سامانه به تقويم نيز لينك مي‌شود. ',
	'texte_mise_a_niveau_base_1' => 'شما فايلهاى اسپيپ را نو كرديد.
اكنون بايد داده پى هاى سايت را ميزان كنيد.
 ',
	'texte_modifier_article' => 'مقاله را اصلاح كنيد :',
	'texte_multilinguisme' => 'اگر مايل به اداره موضوع‌ها به چند زبان هستيد، با ناوبري پيچيده، ميتوانيد، بر اساس سازماندهي سايت خود، يك منوي بخش زبان براي اين موضوع‌ها اضافه كنيد.',
	'texte_multilinguisme_trad' => 'شما همچنين ميتوانيد يك سيستم اداره پيوندهاى بين ترجمه‌هاي  گوناگون اين موضوع‌ها را فعال كنيد.',
	'texte_non_compresse' => '<i>فشرده نشده</i> (سرور شما اين عملكرد را قبول نميكند)',
	'texte_nouvelle_version_spip_1' => 'شما نسخه جديد اسپيپ را نصب كرده ايد.',
	'texte_nouvelle_version_spip_2' => 'اين نسخه جديد نياز به روزآمدسازي كامل تر دارد. اگر شما وب مستر سايت هستيد لطفا فايل @connect@ را پاك كنيد و دوباره نصب اسپيپ را از سر بگيريد تا پارامترهاى اتصال داده پى ها نو شوند.<p>(اگر شما پارامترهاى اتصال را فراموش كرده‌ايد، ميتوانيد به فايل زير مراجعه كنيد @connect@ (پيش از اينكه آنرا حذف كنيد...)</p>',
	'texte_operation_echec' => 'به صفحه پيشين برگرديد، يك پايگاه انتخاب كنيد يا اينكه جديدش را بسازيد.اطلاعات داده شده توسط ميزبانتان را در مدنظر داشته باشيد.',
	'texte_plus_trois_car' => 'بيش از سه حرف',
	'texte_plusieurs_articles' => 'براى اين جستجو چندين نويسنده پيدا شده: "@cherche_auteur@"',
	'texte_port_annuaire' => '(ارزش مشخص شده عموما مناسب است)',
	'texte_presente_plugin' => 'این صفحه فهرست plugins موجود را نشان میدهد. برای فعال کردن آنها مربع مربوطه را علامت بزنید.',
	'texte_proposer_publication' => 'هنگاميكه مقاله تان تمام شد ميتوانيد پيشنهاد انتشارش را بكنيد.',
	'texte_proxy' => 'در بعضى موارد (اينترانت، شبكه هاى محافظت شده،...) براى دسترسى به سايتهاى پيوندى نياز به پروكسى داريد. <i>proxy HTTP</i> در اينصورت آدرسها را در زير به اين شكل مشخص كنيد
  <tt><html>http://proxy:8080</html></tt>معمولا بهتر است اين مربع را خالى بگذاريد ',
	'texte_publication_articles_post_dates' => 'اسپيپ بايد چه واكنشى را در مورد مقالاتى كه موعد تاريخ انتشارشان در آينده منقضى ميشود بپذيرد؟',
	'texte_rappel_selection_champs' => '[اين موارد را درست انتخاب كنيد.]',
	'texte_recalcul_page' => 'اگر ميخواهيد تنها يك صفحه را نو كنيد، بهتر است كه به قسمت همگانى رويد و بروى دكمه «تازه كنيد» كليك كنيد.',
	'texte_recuperer_base' => 'داده پى ها را ترميم كنيد',
	'texte_reference_mais_redirige' => 'مقاله پيوندى در سايت اسپيپ، كه به آدرس ديگرى هدايت شده.',
	'texte_requetes_echouent' => '<b>هنگاميكه بعضى از جويش‌هاي اس كيو ال بدون هيچ دليلى به صورت سيستماتيك پذيرفته نميشوند، اين احتمال وجود دارد كه از پايگاه داده‌‌ها باشد.</b><p>
سرور اس كيوال توانائى ترميم جداولش را هنگاميكه براثر حادثه خراب شده باشند دارد.شما ميتوانيد اقدام به ترميم آنها كنيد، در صورت شكست، يك كپى از فهرست اشكالات را نگه داريد ...</p><p>
اگر مشكل حل نشد، با ميزبانتان تماس بگيريد.</p>',
	'texte_selection_langue_principale' => 'شما ميتوانيد در زير زبان اصلى سايت را انتخاب كنيد.اين گزينش شما را مجبور به نوشتن در زبان انتخابى نميكند،<ul><li> ولى امكان تعيين تاريخ، نوع موتورى كه اسپيپ بايد استفاده كند تا متون قابل رويت باشند، زبان پرسشنامه ها در قسمت همگانى سايت و همچنين زبان قسمت خصوصى را ميدهد.<ul><li>',
	'texte_sous_titre' => 'عنوان فرعى',
	'texte_statistiques_visites' => 'خطوط پررنگ : يكشنبه /    منحنى پررنگ : ميانگين تحولات  ',
	'texte_statut_attente_validation' => 'در انتظار تائيد',
	'texte_statut_publies' => 'برروى تارنما منتشر شود',
	'texte_statut_refuses' => 'پذيرفته نشده',
	'texte_suppression_fichiers' => 'از اين فرمان براى حذف تمام فايلها موجود در فايلهاى موقت اسپيپ استفاده كنيد.
اين بشما امكان نو كردن تمام صفحات را ميدهد بويژه اگر شما تغييرات مهمى در نما يا در ساختار سايت داده باشيد.',
	'texte_sur_titre' => 'سر عنوان',
	'texte_table_ok' => 'اين جدول درست است :',
	'texte_tentative_recuperation' => 'كوشش براى تعمير',
	'texte_tenter_reparation' => 'اقدام به ترميم داده پى ها كنيد',
	'texte_test_proxy' => 'براى امتحان اين پروكسى، آدرس سايت تارنماى مورد دلخواهتان را در اينجا درج كنيد.',
	'texte_titre_02' => 'عنوان :',
	'texte_titre_obligatoire' => '<b>عنوان</b> [اجبارى]',
	'texte_travail_article' => '@nom_auteur_modif@ بروى اين مقاله @date_diff@ پيش كار كرده است.',
	'texte_travail_collaboratif' => 'اين امكان وجود دارد كه يك مقاله توسط چند نويسنده نوشته شده باشد. اسپيپ ميتواند مقالات تازه وارد شده را نشان دهد تا از تغييرات همزمان جلوگيرى كند.
اين گزينش معمولا غير فعال ميباشد تا از اعلان خبرهاى بيموقع جلوگيرى كند.
',
	'texte_vide' => 'خالى',
	'texte_vider_cache' => 'فايل هاى موقت را خالى كنيد',
	'titre_admin_tech' => 'نگهدارى و تعميرات فنى',
	'titre_admin_vider' => 'نگهدارى و تعميرات فنى',
	'titre_ajouter_un_auteur' => 'افزودن يك مؤلف',
	'titre_ajouter_un_mot' => 'افزودن يك كليد-واژه',
	'titre_cadre_afficher_article' => 'مقالات را نمايش دهيد',
	'titre_cadre_afficher_traductions' => ' وضعيت برگردانها را براى زبانهاي زير نشان دهيد :',
	'titre_cadre_ajouter_auteur' => 'يك نويسنده اضافه كنيد :',
	'titre_cadre_interieur_rubrique' => 'در داخل بخش',
	'titre_cadre_numero_auteur' => 'نويسنده شماره',
	'titre_cadre_numero_objet' => '@objet@ شماره‌ي: ',
	'titre_cadre_signature_obligatoire' => '<b>امضا</b> [اجبارى]<br />',
	'titre_config_contenu_notifications' => 'اخطاريه‌ها',
	'titre_config_contenu_prive' => 'در قسمت شخصي',
	'titre_config_contenu_public' => 'در سايت همگاني',
	'titre_config_fonctions' => 'پيكربندى سايت',
	'titre_config_langage' => 'پيكربندي زبان',
	'titre_configuration' => 'پيكربندى سايت',
	'titre_configurer_preferences' => 'پيكربندي ترجيح‌هاي شما',
	'titre_conflit_edition' => 'ناسازگاري هنگام ويرايش ',
	'titre_connexion_ldap' => 'گزينش : <b>اتصال LDAP</b>',
	'titre_groupe_mots' => 'گروه واژه ها :',
	'titre_identite_site' => 'هويت سايت',
	'titre_langue_article' => 'زبان مقاله',
	'titre_langue_rubrique' => 'زبان بخش',
	'titre_langue_trad_article' => 'زبان و ترجمه هاى مقاله ',
	'titre_les_articles' => 'مقالات',
	'titre_messagerie_agenda' => 'سامانه پيام‌دهي و روزنويسي ',
	'titre_naviguer_dans_le_site' => 'در سايت گردش كنيد',
	'titre_nouvelle_rubrique' => 'بخش جديد',
	'titre_numero_rubrique' => 'بخش شماره :',
	'titre_page_articles_edit' => 'اصلاح كنيد :@titre@',
	'titre_page_articles_page' => 'مقالات',
	'titre_page_articles_tous' => 'تمام سايت',
	'titre_page_calendrier' => 'سالنما @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'پيكربندى سايت',
	'titre_page_delete_all' => 'حذف كامل و غير قابل برگشت',
	'titre_page_recherche' => 'نتايج جستجوى@recherche@',
	'titre_page_statistiques_referers' => 'آمار (پيوندهاى وارد شده)',
	'titre_page_upgrade' => 'همسان كردن اسپيپ',
	'titre_publication_articles_post_dates' => 'انتشار مقالات با تاريخ آينده',
	'titre_reparation' => 'تعمير',
	'titre_suivi_petition' => 'دنباله درخواستها',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'تمام ترجمه هاى اين مقاله :',
	'trad_delier' => 'پيوند به اين ترجمه‌هاي متوقف شود',
	'trad_lier' => 'اين مقاله برگردان مقاله شماره زير ميباشد :',
	'trad_new' => 'ترجمه‌ي جديد',

	// U
	'utf8_convert_erreur_orig' => 'اشتباه: نویسه های @charset@ پذیرفته نمیشود.',

	// V
	'version' => 'نسخه:'
);

?>
